@@ -14,11 +14,13 @@ use Carp qw (cluck croak carp) ;
 
 use FindBin;                 # locate this script
 use lib "$FindBin::Bin/../..";  # use the parent directory
-
-use base qw( Metabolomics::Banks ) ;
-
+use Metabolomics::Banks qw( :all ) ;
 use Metabolomics::Utils qw( :all ) ;
 
+require Exporter;
+
+our @ISA = qw(Exporter);
+
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -48,36 +50,27 @@ Metabolomics::Banks::AbInitioFragments - Perl extension for Ab Initio Fragments
 
 =head1 VERSION
 
-Version 0.3 - Adding POD
-Version 0.4 - Updating Fragments/Adducts/isotopes listing
-Version 0.5 - Completing object properties
+Version 0.2
 
 =cut
 
-our $VERSION = '0.5';
+our $VERSION = '0.2';
 
 
 =head1 SYNOPSIS
 
-use Metabolomics::Banks::AbInitioFragments;
+    use Metabolomics::Banks::AbInitioFragments;
 
 =head1 DESCRIPTION
 
-Metabolomics::Banks::AbInitioFragments is a full package for Perl allowing to build a generic Perl bank object from Ab Initio fragments resource.
+	Metabolomics::Banks::AbInitioFragments is a full package for Perl allowing to build a generic Perl bank object from Ab Initio fragments resource.
+	
 
 =head1 EXPORT
 
-use Metabolomics::Banks::AbInitioFragments qw( :all ) ;
+=head1 SUBROUTINES/METHODS
 
-=head1 PUBLIC METHODS 
-
-
-=head2 Metabolomics::Banks::AbInitioFragments
-
-
-=over 4
-
-=item new 
+=head2 METHOD new
 
 	## Description : new
 	## Input : $self
@@ -88,36 +81,173 @@ use Metabolomics::Banks::AbInitioFragments qw( :all ) ;
 
 sub new {
     ## Variables
-    my ($class,$args) = @_;
     my $self={};
-        
+    bless($self) ;
+    
     $self = Metabolomics::Banks->new() ;
     
     $self->{_DATABASE_NAME_} = 'Ab Initio Fragments' ;
-    $self->{_DATABASE_TYPE_} = 'FRAGMENT' ;
-    $self->{_POLARITY_} =  $args->{POLARITY} ;
     $self->{_DATABASE_VERSION_} = '1.0' ;
     $self->{_DATABASE_ENTRIES_NB_} = 'database_entries_nb' ;
     $self->{_DATABASE_URL_} = 'database_url' ;
     $self->{_DATABASE_DOI_} = 'database_doi' ;
     $self->{_FRAGMENTS_} = [] ;
     ## _DATABASE_ENTRIES_
-    bless($self) ;
     
     return $self ;
 }
 ### END of SUB
 
+=head2 METHOD __refBloodExposomeEntry__
 
-=item METHOD getFragmentsFromSource
+	## Description : init a new ab initio fragment entry
+	## Input : void	
+	## Output : refEntry
+	## Usage : $self->__refAbInitioFragment__() ;
+	
+=cut
+## START of SUB
+sub __refAbInitioFragment__ {
+    ## Variables
+    my ($class,$args) = @_;
+    my $self={};
+
+    bless($self) ;
+    
+    $self->{_TYPE_} = 'type' ; # STRING as adducts, fragment or isotope
+    $self->{_LOSSES_OR_GAINS_} = 'losses_or_gains' ;
+    $self->{_DELTA_MASS_} = 'delta_mass' ;
+    $self->{_ANNOTATION_IN_POS_MODE_} = 'annotation_in_pos_mode' ;
+    $self->{_ANNOTATION_IN_NEG_MODE_} = 'annotation_in_neg_mode' ;
+
+    return $self ;
+}
+### END of SUB
+
+# * * * * * * * * * *get/setter  * * * * * * * * * *#
+
+=head2 METHOD _getANNOTATION_IN_NEG_MODE
+
+	## Description : _getANNOTATION_IN_NEG_MODE
+	## Input : void
+	## Output : $ANNOTATION_IN_NEG_MODE
+	## Usage : my ( $ANNOTATION_IN_NEG_MODE ) = _getANNOTATION_IN_NEG_MODE () ;
+	
+=cut
+## START of SUB
+sub _getFragment_ANNOTATION_IN_NEG_MODE {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $ANNOTATION_IN_NEG_MODE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_IN_NEG_MODE_}) and ( $self->{_ANNOTATION_IN_NEG_MODE_} ne '' ) ) {	$ANNOTATION_IN_NEG_MODE = $self->{_ANNOTATION_IN_NEG_MODE_} ; }
+    #else {	 $ANNOTATION_IN_NEG_MODE = undef ; warn "[WARN] the method _getFragment_ANNOTATION_IN_NEG_MODE get a undef or null string value\n" ; }
+    
+    return ( $ANNOTATION_IN_NEG_MODE ) ;
+}
+### END of SUB
+
+
+
+=head2 METHOD _getANNOTATION_IN_POS_MODE
+
+	## Description : _getANNOTATION_IN_POS_MODE
+	## Input : void
+	## Output : $ANNOTATION_IN_POS_MODE
+	## Usage : my ( $ANNOTATION_IN_POS_MODE ) = _getANNOTATION_IN_POS_MODE () ;
+	
+=cut
+## START of SUB
+sub _getFragment_ANNOTATION_IN_POS_MODE {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $ANNOTATION_IN_POS_MODE = undef ;
+    
+    if ( (defined $self->{_ANNOTATION_IN_POS_MODE_}) and ( $self->{_ANNOTATION_IN_POS_MODE_} ne '' ) ) {	$ANNOTATION_IN_POS_MODE = $self->{_ANNOTATION_IN_POS_MODE_} ; }
+    #else {	 $ANNOTATION_IN_POS_MODE = undef ; warn "[WARN] the method _getFragment_ANNOTATION_IN_POS_MODE get a undef or null string value\n" ; }
+    
+    return ( $ANNOTATION_IN_POS_MODE ) ;
+}
+### END of SUB
+
+
+=head2 METHOD _getDELTA_MASS
+
+	## Description : _getDELTA_MASS
+	## Input : void
+	## Output : $DELTA_MASS
+	## Usage : my ( $DELTA_MASS ) = _getDELTA_MASS () ;
+	
+=cut
+## START of SUB
+sub _getFragment_DELTA_MASS {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $DELTA_MASS = undef ;
+    
+    if ( (defined $self->{_DELTA_MASS_}) and ( $self->{_DELTA_MASS_} > 0 ) or $self->{_DELTA_MASS_} < 0  ) {	$DELTA_MASS = $self->{_DELTA_MASS_} ; }
+    else {	 $DELTA_MASS = 0 ; warn "[WARN] the method _getFragment_DELTA_MASS can't _get a undef or non numerical value\n" ; }
+    
+    return ( $DELTA_MASS ) ;
+}
+### END of SUB
+
+=head2 METHOD _getTYPE
+
+	## Description : _getTYPE
+	## Input : void
+	## Output : $TYPE
+	## Usage : my ( $TYPE ) = _getTYPE () ;
+	
+=cut
+## START of SUB
+sub _getFragment_TYPE {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $TYPE = undef ;
+    
+    if ( (defined $self->{_TYPE_}) and ( $self->{_TYPE_} ne '' ) ) {	$TYPE = $self->{_TYPE_} ; }
+    else {	 $TYPE = undef ; warn "[WARN] the method _getFragment_TYPE can't _get a undef or non numerical value\n" ; }
+    
+    return ( $TYPE ) ;
+}
+### END of SUB
+
+=head2 METHOD _getLOSSES_OR_GAINS
+
+	## Description : _getLOSSES_OR_GAINS
+	## Input : void
+	## Output : $LOSSES_OR_GAINS
+	## Usage : my ( $LOSSES_OR_GAINS ) = _getLOSSES_OR_GAINS () ;
+	
+=cut
+## START of SUB
+sub _getFragment_LOSSES_OR_GAINS {
+    ## Retrieve Values
+    my $self = shift ;
+    
+    my $LOSSES_OR_GAINS = undef ;
+    
+    if ( (defined $self->{_LOSSES_OR_GAINS_}) and ( $self->{_LOSSES_OR_GAINS_} ne '' ) ) {	$LOSSES_OR_GAINS = $self->{_LOSSES_OR_GAINS_} ; }
+    else {	 $LOSSES_OR_GAINS = undef ; warn "[WARN] the method _getFragment_LOSSES_OR_GAINS can't _get a undef or non numerical value\n" ; }
+    
+    return ( $LOSSES_OR_GAINS ) ;
+}
+### END of SUB
+
+
+=head2 METHOD getFragmentsFromSource
 
 	## Description : get the list of theorical fragments from $source file
 	## Input : $source
 	## Output : $theoFragments
 	## Usage : my ( $theoFragments ) = getFragmentsFromSource ( $source ) ;
-
+	
 =cut
-
 ## START of SUB
 sub getFragmentsFromSource {
     ## Retrieve Values
@@ -127,29 +257,13 @@ sub getFragmentsFromSource {
     my $entriesNb = 0 ;
     
     if (!defined $source) {
-    	
-    	
-    	if ($VERSION == 0.3) {
-    		## v1.0 file
-    		$source = dist_file('Metabolomics-Fragment-Annotation', 'MS_fragments-adducts-isotopes.txt');
-	    	if (-e $source) {
-	    		print "loading v1.0 $source...\n" ;
-	    	}
-	    	else {
-	    		croak "The v1.0 source file ('MS_fragments-adducts-isotopes.txt') does not exist at this path\n" ;
-	    	}
-    		
+
+    	$source = dist_file('Metabolomics-Fragment-Annotation', 'MS_fragments-adducts-isotopes.txt');
+    	if (-e $source) {
+    		print "loading $source...\n" ;
     	}
-    	elsif ($VERSION >= 0.4) {
-    		## v1.0 file
-    		$source = dist_file('Metabolomics-Fragment-Annotation', 'MS_fragments-adducts-isotopes__V1.1.txt');
-    		
-	    	if (-e $source) {
-	    		print "loading v1.1 $source...\n" ;
-	    	}
-	    	else {
-	    		croak "The v1.1 source file ('MS_fragments-adducts-isotopes__V1.1.txt') does not exist at this path\n" ;
-	    	}
+    	else {
+    		croak "The source file ('MS_fragments-adducts-isotopes.txt') does not exist at this path\n" ;
     	}
     }
     
@@ -197,31 +311,25 @@ sub getFragmentsFromSource {
 ### END of SUB
 
 
-=item METHOD buildTheoPeakBankFromFragments
+=head2 METHOD buildTheoPeakBankFromFragments
 
 	## Description : building a bank integrating each potential fragments from a parent ion
 	## Input : $refBank, $mzParent, $mode (POSITIVE, NEGATIVE, NEUTRAL), $stateMolecule (POS, NEG, NEU)
 	## Output : $ionBank
 	## Usage : my ( $ionBank ) = buildTheoPeakBankFromFragments ( $refBank, $mzParent ) ;
-
+	
 =cut
-
 ## START of SUB
 sub buildTheoPeakBankFromFragments {
     ## Retrieve Values
     my $self = shift ;
-    my ( $mzParent, $mode, $stateMolecule, $isotopicAddingStatus ) = @_;
+    my ( $mzParent, $mode, $stateMolecule ) = @_;
 
     my $fragments = $self->_getFragments();
 
     foreach my $fragment (@{$fragments}) {
     	## Addition ion mz and theo fragment and filter negative obtained mz
     	
-    	## Avoid to generate isotopic massif
-    	if ( (defined $isotopicAddingStatus) and ($isotopicAddingStatus eq 'FALSE') and ( $fragment->_getFragment_TYPE() eq 'isotope'  ) ) {
-    		next ;
-    	}
-    	
     	my $fragMass = $fragment->_getFragment_DELTA_MASS() ;
     	
     	my $mzToAdjust = $mzParent ;
@@ -287,15 +395,14 @@ sub buildTheoPeakBankFromFragments {
 }
 ### END of SUB
 
-=item METHOD buildTheoDimerFromMz
+=head2 METHOD buildTheoDimerFromMz
 
 	## Description : build potential dimers/trimers in NEG/POS mode
 	## Input : $Mz, $mode
 	## Output : $oBank
 	## Usage : my ( $oBank ) = buildTheoDimerFromMz ( $Mz, $mode ) ;
-
+	
 =cut
-
 ## START of SUB
 sub buildTheoDimerFromMz {
     ## Retrieve Values
@@ -315,7 +422,7 @@ sub buildTheoDimerFromMz {
 			'2M+ACN+Na'  => 64.015765 ,
     	) ;
     	
-    	foreach my $adduct ( sort {lc $a cmp lc $b} keys %posAdducts) {
+    	foreach my $adduct (keys %posAdducts) {
     		
     		my $adductMass = $posAdducts{$adduct} ;
     		## Only for Dimers !!!!
@@ -350,7 +457,7 @@ sub buildTheoDimerFromMz {
 			'2M+Hac-H' => 59.013851 ,
     	) ;
     	
-    	foreach my $adduct (sort {lc $a cmp lc $b} keys %negAdducts) {
+    	foreach my $adduct (keys %negAdducts) {
     		
     		my $adductMass = $negAdducts{$adduct} ;
     		## Only for Dimers !!!!
@@ -370,7 +477,7 @@ sub buildTheoDimerFromMz {
 	    	$oPeak->_setPeak_ANNOTATION_NAME ( $adduct );
 			$oPeak->_setPeak_ANNOTATION_IN_NEG_MODE (  $adduct ) ;
 			
-#			print Dumper $oPeak ;
+			print Dumper $oPeak ;
 			
 			$self->_addPeakList('_THEO_PEAK_LIST_', $oPeak) ;
     	}
@@ -383,15 +490,17 @@ sub buildTheoDimerFromMz {
 }
 ### END of SUB
 
-=item METHOD isotopicAdvancedCalculation
+
+
+
+=head2 METHOD isotopicAdvancedCalculation
 
 	## Description : if a fragment is present in theorical bank, compute its isotopic couple.
 	## Input : $refBank
 	## Output : $ionBank
 	## Usage : my ( $ionBank ) = isotopicAdvancedCalculation ( $refBank ) ;
-
+	
 =cut
-
 ## START of SUB
 sub isotopicAdvancedCalculation {
     ## Retrieve Values
@@ -421,7 +530,7 @@ sub isotopicAdvancedCalculation {
    		# find if it is a fragment
    		if ( defined $peak->_getPeak_ANNOTATION_TYPE() ) {
    			
-   			if ( ($peak->_getPeak_ANNOTATION_TYPE() eq 'fragment' ) or ($peak->_getPeak_ANNOTATION_TYPE() eq 'adduct' ) or ($peak->_getPeak_ANNOTATION_TYPE() eq 'dimeric adduct' ) ) {
+   			if ( ($peak->_getPeak_ANNOTATION_TYPE() eq 'fragment' ) or ($peak->_getPeak_ANNOTATION_TYPE() eq 'adduct' ) ) {
    				
    				my $peakMass = $peak->_getPeak_COMPUTED_MONOISOTOPIC_MASS() ;
    				my $peakAnnotationName = $peak->_getPeak_ANNOTATION_NAME() ;
@@ -432,7 +541,7 @@ sub isotopicAdvancedCalculation {
    				$peakAnnotationInPosMode = $peak->_getPeak_ANNOTATION_IN_POS_MODE() if ( $peak->_getPeak_ANNOTATION_IN_POS_MODE() ) ;
    				$peakAnnotationInNegMode = $peak->_getPeak_ANNOTATION_IN_NEG_MODE() if ( $peak->_getPeak_ANNOTATION_IN_NEG_MODE() ) ;
    				
-   				foreach my $isotope ( sort {lc $a cmp lc $b} keys %isotopes) {
+   				foreach my $isotope (keys %isotopes) {
    					
    					my $isotopeMass = $isotopes{$isotope} ;
    					
@@ -464,170 +573,17 @@ sub isotopicAdvancedCalculation {
 }
 ### END of SUB
 
-=back
-
-=head1 PRIVATE METHODS
-
-=head2 Metabolomics::Banks::AbInitioFragments
-
-=over 4
-
-=item PRIVATE_ONLY __refBloodExposomeEntry__
-
-	## Description : init a new ab initio fragment entry
-	## Input : void	
-	## Output : refEntry
-	## Usage : $self->__refAbInitioFragment__() ;
-
-=cut
-
-## START of SUB
-sub __refAbInitioFragment__ {
-    ## Variables
-    my ($class,$args) = @_;
-    my $self={};
-
-    bless($self) ;
-    
-    $self->{_TYPE_} = 'type' ; # STRING as adducts, fragment or isotope
-    $self->{_LOSSES_OR_GAINS_} = 'losses_or_gains' ;
-    $self->{_DELTA_MASS_} = 'delta_mass' ;
-    $self->{_ANNOTATION_IN_POS_MODE_} = 'annotation_in_pos_mode' ;
-    $self->{_ANNOTATION_IN_NEG_MODE_} = 'annotation_in_neg_mode' ;
-
-    return $self ;
-}
-### END of SUB
-
-# * * * * * * * * * *get/setter  * * * * * * * * * *#
-
-=item PRIVATE_ONLY _getANNOTATION_IN_NEG_MODE
-
-	## Description : _getANNOTATION_IN_NEG_MODE
-	## Input : void
-	## Output : $ANNOTATION_IN_NEG_MODE
-	## Usage : my ( $ANNOTATION_IN_NEG_MODE ) = _getANNOTATION_IN_NEG_MODE () ;
-
-=cut
-
-## START of SUB
-sub _getFragment_ANNOTATION_IN_NEG_MODE {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $ANNOTATION_IN_NEG_MODE = undef ;
-    
-    if ( (defined $self->{_ANNOTATION_IN_NEG_MODE_}) and ( $self->{_ANNOTATION_IN_NEG_MODE_} ne '' ) ) {	$ANNOTATION_IN_NEG_MODE = $self->{_ANNOTATION_IN_NEG_MODE_} ; }
-    #else {	 $ANNOTATION_IN_NEG_MODE = undef ; warn "[WARN] the method _getFragment_ANNOTATION_IN_NEG_MODE get a undef or null string value\n" ; }
-    
-    return ( $ANNOTATION_IN_NEG_MODE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getANNOTATION_IN_POS_MODE
-
-	## Description : _getANNOTATION_IN_POS_MODE
-	## Input : void
-	## Output : $ANNOTATION_IN_POS_MODE
-	## Usage : my ( $ANNOTATION_IN_POS_MODE ) = _getANNOTATION_IN_POS_MODE () ;
-
-=cut
-
-## START of SUB
-sub _getFragment_ANNOTATION_IN_POS_MODE {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $ANNOTATION_IN_POS_MODE = undef ;
-    
-    if ( (defined $self->{_ANNOTATION_IN_POS_MODE_}) and ( $self->{_ANNOTATION_IN_POS_MODE_} ne '' ) ) {	$ANNOTATION_IN_POS_MODE = $self->{_ANNOTATION_IN_POS_MODE_} ; }
-    #else {	 $ANNOTATION_IN_POS_MODE = undef ; warn "[WARN] the method _getFragment_ANNOTATION_IN_POS_MODE get a undef or null string value\n" ; }
-    
-    return ( $ANNOTATION_IN_POS_MODE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getDELTA_MASS
-
-	## Description : _getDELTA_MASS
-	## Input : void
-	## Output : $DELTA_MASS
-	## Usage : my ( $DELTA_MASS ) = _getDELTA_MASS () ;
-
-=cut
-
-## START of SUB
-sub _getFragment_DELTA_MASS {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $DELTA_MASS = undef ;
-    
-    if ( (defined $self->{_DELTA_MASS_}) and ( $self->{_DELTA_MASS_} > 0 ) or $self->{_DELTA_MASS_} < 0  ) {	$DELTA_MASS = $self->{_DELTA_MASS_} ; }
-    else {	 $DELTA_MASS = 0 ; warn "[WARN] the method _getFragment_DELTA_MASS can't _get a undef or non numerical value\n" ; }
-    
-    return ( $DELTA_MASS ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getFragment_TYPE
-
-	## Description : _getFragment_TYPE
-	## Input : void
-	## Output : $TYPE
-	## Usage : my ( $TYPE ) = _getFragment_TYPE () ;
-
-=cut
-
-## START of SUB
-sub _getFragment_TYPE {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $TYPE = undef ;
-    
-    if ( (defined $self->{_TYPE_}) and ( $self->{_TYPE_} ne '' ) ) {	$TYPE = $self->{_TYPE_} ; }
-    else {	 $TYPE = undef ; warn "[WARN] the method _getFragment_TYPE can't _get a undef or non numerical value\n" ; }
-    
-    return ( $TYPE ) ;
-}
-### END of SUB
-
-=item PRIVATE_ONLY _getLOSSES_OR_GAINS
-
-	## Description : _getLOSSES_OR_GAINS
-	## Input : void
-	## Output : $LOSSES_OR_GAINS
-	## Usage : my ( $LOSSES_OR_GAINS ) = _getLOSSES_OR_GAINS () ;
-
-=cut
-
-## START of SUB
-sub _getFragment_LOSSES_OR_GAINS {
-    ## Retrieve Values
-    my $self = shift ;
-    
-    my $LOSSES_OR_GAINS = undef ;
-    
-    if ( (defined $self->{_LOSSES_OR_GAINS_}) and ( $self->{_LOSSES_OR_GAINS_} ne '' ) ) {	$LOSSES_OR_GAINS = $self->{_LOSSES_OR_GAINS_} ; }
-    else {	 $LOSSES_OR_GAINS = undef ; warn "[WARN] the method _getFragment_LOSSES_OR_GAINS can't _get a undef or non numerical value\n" ; }
-    
-    return ( $LOSSES_OR_GAINS ) ;
-}
-### END of SUB
 
 
 __END__
 
-=back
-
 =head1 AUTHOR
 
-Franck Giacomoni, C<< <franck.giacomoni at inrae.fr> >>
+Franck Giacomoni, C<< <franck.giacomoni at inra.fr> >>
 
 =head1 SEE ALSO
 
-All information about Metabolomics::Fragment::Annotation would be find here: https://services.pfem.clermont.inra.fr/gitlab/fgiacomoni/metabolomics-fragnot
+All information about Metabolomics::Fragment would be find here: https://services.pfem.clermont.inra.fr/gitlab/fgiacomoni/metabolomics-fragnot
 
 =head1 BUGS
 
@@ -665,7 +621,6 @@ L<https://metacpan.org/release/Metabolomics-Fragment-Annotation>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thank you to INRAE and All metabolomics colleagues.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -673,9 +628,9 @@ CeCILL Copyright (C) 2019 by Franck Giacomoni
 
 Initiated by Franck Giacomoni
 
-followed by INRAE PFEM team
+followed by INRA PFEM team
 
-Web Site = INRAE PFEM
+Web Site = INRA PFEM
 
 
 =cut
